summaryrefslogtreecommitdiffstats
path: root/lib/koproperty/factory.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/koproperty/factory.h')
-rw-r--r--lib/koproperty/factory.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/lib/koproperty/factory.h b/lib/koproperty/factory.h
index 8abc93b3..8aca5538 100644
--- a/lib/koproperty/factory.h
+++ b/lib/koproperty/factory.h
@@ -43,17 +43,17 @@ class FactoryManagerPrivate;
class KOPROPERTY_EXPORT CustomPropertyFactory : public TQObject
{
public:
- CustomPropertyFactory(TQObject *tqparent);
+ CustomPropertyFactory(TQObject *parent);
virtual ~CustomPropertyFactory();
/*! \return a new instance of custom property for \a tqparent.
Implement this for property types you want to support.
- Use tqparent->type() to get type of the property. */
- virtual CustomProperty* createCustomProperty(Property *tqparent) = 0;
+ Use parent->type() to get type of the property. */
+ virtual CustomProperty* createCustomProperty(Property *parent) = 0;
/*! \return a new instance of custom property for \a property.
Implement this for property editor types you want to support.
- Use tqparent->type() to get type of the property. */
+ Use parent->type() to get type of the property. */
virtual Widget* createCustomWidget(Property *property) = 0;
};
@@ -81,12 +81,12 @@ class KOPROPERTY_EXPORT CustomPropertyFactory : public TQObject
\section custom_prop_composed Using Custom Properties to create composed properties
Use a composed property when you need more than one editor for a property. Examples
are rect, size or point properties.
- If you create a composed property, both tqparent and tqchildren properties must have custom
+ If you create a composed property, both parent and tqchildren properties must have custom
(different) types.
- Child properties are created in CustomProperty constructor of the <b>tqparent</b> type,
- by adding CustomProperty::property() as tqparent in Property constructor.\n
+ Child properties are created in CustomProperty constructor of the <b>parent</b> type,
+ by adding CustomProperty::property() as parent in Property constructor.\n
Child properties should return handleValue() == true and in CustomProperty::setValue(),
- tqparent's Property::setValue() should be called, making sure that useCustomProperty argument is set
+ parent's Property::setValue() should be called, making sure that useCustomProperty argument is set
to false.\n
Parent's handleValue() should be set to false, unless you cannot store the property in a TQVariant.
You just need to update tqchildren's value, making sure that useCustomProperty argument is set
@@ -116,7 +116,7 @@ class KOPROPERTY_EXPORT FactoryManager : public TQObject
/*! Registers a custom factory \a factory for handling property editor for \a editorType.
This custom factory will be used before defaults when widgetForProperty() is called.
\a creator is not owned by this Factory object, but it's good idea
- to instantiate CustomPropertyFactory object itself as a child of Factory tqparent. For example:
+ to instantiate CustomPropertyFactory object itself as a child of Factory parent. For example:
\code
MyCustomPropertyFactory *f = new MyCustomPropertyFactory(KoProperty::Factory::self());
KoProperty::Factory::self()->registerEditor( MyCustomType, f );
@@ -133,7 +133,7 @@ class KOPROPERTY_EXPORT FactoryManager : public TQObject
CustomPropertyFactory *factoryForEditorType(int type);
/*! Creates and returns the editor for given property type.
- Warning: editor and viewer widgets won't have tqparent widget. Property editor
+ Warning: editor and viewer widgets won't have parent widget. Property editor
cares about reparenting and deletion of returned widgets in machines.
If \a createWidget is false, just create child properties, not widget.*/
Widget* createWidgetForProperty(Property *property);
@@ -150,7 +150,7 @@ class KOPROPERTY_EXPORT FactoryManager : public TQObject
/*! This function is called in Property::Property() to create (optional)
custom property. It creates the custom property for built-in types, or
calls one of createCustomProperty function previously registered for other types. */
- CustomProperty* createCustomProperty(Property *tqparent);
+ CustomProperty* createCustomProperty(Property *parent);
/*! \return a pointer to a property factory instance.*/
static FactoryManager* self();
@@ -43,17 +43,17 @@ class FactoryManagerPrivate;
virtual ~CustomPropertyFactory();
- /*! \return a new instance of custom property for \a tqparent.
+ /*! \return a new instance of custom property for \a parent.
Implement this for property types you want to support.